==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sv/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "IP-adressgruppen $1 har raderats.");
regGS("IP Group $1 added for user $2", "IP-grupp $1 tillagd för användaren $2");
regGS("User permissions for $1 changed", "Användarrättigheter för $1 ändrade");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Sektionen $1 raderad. (Utgåva: $2, Publikation: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Sektionen $1 tillagd. (Utgåva: $2, Publikation: $3)");
regGS("Issue $1 changed status to $2", "Utgåva $1 status ändrad till $2");
regGS("User type $1 deleted", "Användartyp $1 raderad");
regGS("User type $1 added", "Användartyp $1 tillagd");
regGS("Topic $1 added to article", "Temat $1 tillagt till artikeln");
regGS("Last", "Sista");
regGS("First", "Första");
regGS("Changed image properties of $1", "Ändrat bildparametrar på $1");
regGS("Article topic $1 deleted", "Artikeltema $1 raderad");
regGS("Article #$1 \"$2\" ($3) created.", "Artikel #$1 \"$2\" ($3) skapad.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Artikel #$1 \"$2\" ($3) översatt till \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Artikel #$1 \"$2\" ($3)  kopierad till Artikel #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Artikel #$1 \"$2\" status ändrad från $3 till $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Artikel #$1 \"$2\" ($3) raderad.");
regGS("Text", "Text");
regGS("Article body", "Artikeltext");
regGS("The default subscription time for $1 has been added.", "Grundprenumerationstiden för $1 har lagts till.");
regGS("Image $1 linked to article $2", "Bild $1 länkad till artikel $2");
regGS("Image $1 unlinked from $2", "Bild $1 avlänkad från artikel $2");
regGS("The image $1 has been added.", "Bilden $1 har lagts till.");
regGS("Image $1 deleted", "Bild $1 raderad");
regGS("Publication $1 changed", "Publikation $1 ändrad");
regGS("Publication $1 deleted", "Publikation $1 raderad");
regGS("Publication $1 added", "Publikation $1 tillagd");
regGS("Issue $1 from publication $2 deleted", "Utgåva $1 från publikationen $2 raderad");
regGS("Issue $1 added in publication $2", "Utgåva $1 tillagd i publikationen $2");
regGS("The article type $1 has been deleted.", "Artikeltypen $1 har raderats.");
regGS("The article type $1 has been added.", "Artikeltypen $1 har lagts till.");
regGS("Article type field $1 created", "Artikeltypfältet $1 har lagts till");
regGS("Article type field $1 deleted", "Artikeltypfältet $1 har raderats");
regGS("Language $1 added", "Språk $1 tillagt");
regGS("Language $1 deleted", "Språk $1 raderat");
regGS("Language $1 modified", "Språk $1 ändrat");
regGS("Country $1 added", "Land $1 tillagt");
regGS("Country $1 deleted", "Land $1 raderat");
regGS("Country name $1 changed", "Landsnamn $1 ändrat");
regGS("The user account $1 has been deleted.", "Användarkontot $1 har raderats.");
regGS("Password changed for $1", "Lösenordet ändrat för $1");
regGS("User account $1 created", "Användarkontot $1 skapat");
regGS("Template $1 uploaded", "Mall $1 uppladdad");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sv/api.php <==
<?php 
regGS("The file uploaded is not an image.", "Den uppladdade filen är inte en bild.");
regGS("Field $1 updated", "Fältet $1 är utdaterat");
regGS("Could not delete record from the database.", "Kunde inte radera posten från databasen.");
regGS("template path", "mallsökväg");
regGS("short names", "korta namn");
regGS("Unable to fetch image from remote server.", "Kunde inte hämta bilden från servern.");
regGS("The article type field $1 has been renamed to $2.", "Artikeltypfältet $1 har döpts om till $2.");
regGS("The article type $1 has been renamed to $2.", "Artikeltypen $1 har döpts om till $2.");
regGS("Article type field $1 changed", "Artikeltypfältet $1 ändrat");
regGS("Article Type $1 translation updated", "Översättningen för artikeltypen $1 uppdaterad");
regGS("The IP address group $1 has been deleted.", "IP-adressgruppen $1 har raderats.");
regGS("IP Group $1 added for user $2", "IP-grupp $1 tillagd för användaren $2");
regGS("User permissions for $1 changed", "Användarrättigheter för $1 ändrade");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Sektionen $1 raderad. (Utgåva: $2, Publikation: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Sektionen $1 tillagd. (Utgåva: $2, Publikation: $3)");
regGS("Issue $1 changed status to $2", "Utgåva $1 status ändrad till $2");
regGS("User type $1 deleted", "Användartyp $1 raderad");
regGS("User type $1 added", "Användartyp $1 tillagd");
regGS("Topic $1 added to article", "Temat $1 tillagt till artikeln");
regGS("Last", "Sista");
regGS("First", "Första");
regGS("Changed image properties of $1", "Ändrat bildparametrar på $1");
regGS("Article topic $1 deleted", "Artikeltema $1 raderad");
regGS("Article #$1 \"$2\" ($3) created.", "Artikel #$1 \"$2\" ($3) skapad.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Artikel #$1 \"$2\" ($3) översatt till \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Artikel #$1 \"$2\" ($3)  kopierad till Artikel #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Artikel #$1 \"$2\" status ändrad från $3 till $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Artikel #$1 \"$2\" ($3) raderad.");
regGS("Single-line Text", "Text");
regGS("Multi-line Text with WYSIWYG", "Artikeltext");
regGS("The default subscription time for $1 has been added.", "Grundprenumerationstiden för $1 har lagts till.");
regGS("Image $1 linked to article $2", "Bild $1 länkad till artikel $2");
regGS("Image $1 unlinked from $2", "Bild $1 avlänkad från artikel $2");
regGS("The image $1 has been added.", "Bilden $1 har lagts till.");
regGS("Image $1 deleted", "Bild $1 raderad");
regGS("Publication $1 changed", "Publikation $1 ändrad");
regGS("Publication $1 deleted", "Publikation $1 raderad");
regGS("Publication $1 added", "Publikation $1 tillagd");
regGS("Issue $1 from publication $2 deleted", "Utgåva $1 från publikationen $2 raderad");
regGS("Issue $1 added in publication $2", "Utgåva $1 tillagd i publikationen $2");
regGS("The article type $1 has been deleted.", "Artikeltypen $1 har raderats.");
regGS("The article type $1 has been added.", "Artikeltypen $1 har lagts till.");
regGS("Article type field $1 created", "Artikeltypfältet $1 har lagts till");
regGS("Article type field $1 deleted", "Artikeltypfältet $1 har raderats");
regGS("Language $1 added", "Språk $1 tillagt");
regGS("Language $1 deleted", "Språk $1 raderat");
regGS("Language $1 modified", "Språk $1 ändrat");
regGS("Country $1 added", "Land $1 tillagt");
regGS("Country $1 deleted", "Land $1 raderat");
regGS("Country name $1 changed", "Landsnamn $1 ändrat");
regGS("The user account $1 has been deleted.", "Användarkontot $1 har raderats.");
regGS("Password changed for $1", "Lösenordet ändrat för $1");
regGS("User account $1 created", "Användarkontot $1 skapat");
regGS("Template $1 uploaded", "Mall $1 uppladdad");
regGS("URL \"$1\" is invalid or is not an image.", "URL \"$1\" är ogiltig eller inte en bild.");
regGS("URL \"$1\" is not an image.", "URL \"$1\" är inte en bild.");
regGS("Topic $1 added", "Temat $1 har lagts till");
regGS("Topic $1 deleted", "Temat $1 raderat");
regGS("Topic $1 updated", "Temat $1 uppdaterat");
?>
